module.exports = {
  components: {
    "resizer": require("vue-resize-handle/unidirectional")
  },
  props: {
    "style": {
      type: Object,
      "default": function() {
        return {
          whiteSpace: "nowrap"
        };
      }
    },
    "name": {
      type: String,
      required: true
    },
    "pinned": {
      type: Boolean,
      "default": false
    },
    "width": {
      type: Number,
      "default": -1
    },
    "defaultWidth": {
      "default": "auto"
    },
    "minWidth": {
      type: Number,
      "default": -1
    },
    "maxWidth": {
      type: Number,
      "default": Number.MAX_VALUE
    },
    "noResize": {
      type: Boolean,
      "default": false
    }
  },
  computed: {
    computedStyle: function() {
      var key, ref, style, val;
      style = {
        width: this.width + 'px',
        lineHeight: "normal"
      };
      ref = this.style;
      for (key in ref) {
        val = ref[key];
        style[key] = val;
      }
      return style;
    },
    defWidth: function() {
      if (this.defaultWidth === "auto") {
        return this.width;
      }
      return +this.defaultWidth;
    }
  },
  data: function() {
    return {
      isColumn: true
    };
  },
  methods: {
    onResize: function(width, oldWidth) {
      if (!this.pinned || (this.pinned && this.$parent.hasWidth(width, oldWidth, this.width))) {
        return this.width = width;
      }
    },
    onResetSize: function() {
      var newWidth;
      if (this.defaultWidth === "auto") {
        newWidth = this.$parent.resetWidth(this.pinned, this.name, this.width);
        if (newWidth < this.minWidth) {
          newWidth = this.minWidth;
        } else if (newWidth > this.maxWidth) {
          newWidth = this.maxWidth;
        }
        return this.width = newWidth;
      }
    },
    processNewWidth: function() {
      if (this.pinned) {
        return this.$nextTick((function(_this) {
          return function() {
            return _this.$parent.onPinnedWidthChange();
          };
        })(this));
      }
    },
    onClick: function(e) {
      return this.$emit("click", e);
    }
  },
  ready: function() {
    if (this.width === -1) {
      this.width = this.$el.clientWidth;
    }
    if (this.minWidth === -1) {
      return this.minWidth = this.$el.clientWidth;
    }
  },
  watch: {
    width: "processNewWidth"
  }
};

if (module.exports.__esModule) module.exports = module.exports.default
;(typeof module.exports === "function"? module.exports.options: module.exports).template = "<div class=dt-header v-bind:style=computedStyle style=display:inline-block;position:relative><div style=overflow:hidden><slot name=header>{{name}}</slot></div><resizer v-if=!noResize v-bind:size=width v-bind:min-size=minWidth v-bind:default-size=defWidth v-bind:max-size=maxWidth @resize=onResize @reset-size=onResetSize></resizer><div v-if=false><slot></slot></div></div>"
