module.exports = {
  mixins: [require("vue-mixins/onElementResize"), require("vue-mixins/fragToString")],
  components: {
    "clusterize": require("vue-clusterize/clusterize")
  },
  props: {
    "bindingName": {
      type: String,
      "default": "data"
    },
    "height": {
      type: Number
    },
    "data": {
      type: Array
    },
    "scrollTop": {
      type: Number,
      "default": 0
    },
    "scrollLeft": {
      type: Number,
      "default": 0
    },
    "manualStart": {
      type: Boolean,
      "default": false
    },
    "autoHeight": {
      type: Boolean,
      "default": false
    }
  },
  computed: {
    position: function() {
      if (this.autoHeight) {
        if (this.disposeResizeCb == null) {
          this.disposeResizeCb = this.onElementResize(this.$el, (function(_this) {
            return function() {
              return _this.clientHeight = _this.$el.clientHeight;
            };
          })(this));
        }
        return "absolute";
      } else {
        if (typeof this.disposeResizeCb === "function") {
          this.disposeResizeCb();
        }
        return "relative";
      }
    },
    style: function() {
      return {
        height: this.height + 'px',
        position: this.position,
        top: this.autoHeight ? 0 : null,
        bottom: this.autoHeight ? 0 : null
      };
    },
    totalHeight: function() {
      if (this.height) {
        return this.height;
      } else {
        if (!this.ready) {
          return null;
        }
        this.clientHeight = this.$el.clientHeight;
        return this.clientHeight;
      }
    },
    clusterizeHeight: function() {
      if (!this.ready) {
        return null;
      }
      return this.totalHeight - this.$els.header.offsetHeight;
    },
    pinnedHeight: function() {
      if (!this.ready) {
        return null;
      }
      return this.clusterizeHeight - this.hovered * this.scrollBarSize.height;
    }
  },
  data: function() {
    return {
      ready: false,
      started: false,
      pinnedContentHeight: -1,
      columnsPinned: [],
      columns: [],
      parentVm: this.$parent,
      hovered: false,
      pinnedWidth: null,
      scrollBarSize: {
        width: 0,
        height: 0
      },
      normalWidth: null,
      clientHeight: null
    };
  },
  methods: {
    hasWidth: function(width, oldWidth, currentWidth) {
      var diff;
      diff = width - currentWidth;
      return diff < 0 || diff < this.$els.header.clientWidth * 0.8 - this.$els.pinnedHeader.offsetWidth;
    },
    resetWidth: function(pinned, name, width) {
      var cell, cluster, clusterize, frag, i, j, len, len1, ref, ref1;
      clusterize = pinned ? this.$refs.clusterizePinned : this.$refs.clusterize;
      ref = clusterize.clusters;
      for (i = 0, len = ref.length; i < len; i++) {
        cluster = ref[i];
        ref1 = cluster.frags;
        for (j = 0, len1 = ref1.length; j < len1; j++) {
          frag = ref1[j];
          cell = frag.node.querySelector(".dt-cell-" + name + ">span");
          if ((cell != null) && cell.offsetWidth > width) {
            width = cell.offsetWidth;
          }
        }
      }
      return width;
    },
    getData: function(first, last, cb) {
      if (this.data != null) {
        return cb(this.data.slice(first, +last + 1 || 9e9));
      } else {
        return this.$emit("get-data", first, last, cb);
      }
    },
    getDataCount: function(cb) {
      if (this.data != null) {
        return cb(this.data.length);
      } else {
        return this.$emit("get-data-count", cb);
      }
    },
    onMouseEnter: function(e) {
      this.hovered = true;
      return this.$nextTick((function(_this) {
        return function() {
          _this.onPinnedWidthChange();
          if (_this.scrollBarSize.width === 0) {
            _this.scrollBarSize.width = _this.$refs.clusterize.$el.offsetWidth - _this.$refs.clusterize.$el.clientWidth;
          }
          if (_this.scrollBarSize.height === 0) {
            return _this.scrollBarSize.height = _this.$refs.clusterize.$el.offsetHeight - _this.$refs.clusterize.$el.clientHeight;
          }
        };
      })(this));
    },
    onMouseLeave: function() {
      this.hovered = false;
      return this.pinnedWidth = null;
    },
    onPinnedWidthChange: function() {
      this.normalWidth = this.$els.header.clientWidth - this.$els.pinnedHeader.offsetWidth;
      if (this.hovered) {
        return this.pinnedWidth = this.$els.pinnedHeader.getBoundingClientRect().width + 'px';
      }
    },
    onScrollY: function(top) {
      return this.scrollTop = top;
    },
    onScrollX: function(left) {
      return this.$els.normalHeader.scrollLeft = left;
    },
    start: function() {
      this.started = true;
      this.$refs.clusterize.start();
      return this.$refs.clusterizePinned.start();
    }
  },
  ready: function() {
    var cellTemplate, cellsTemplate, cellsTemplatePinned, child, i, len, ref, rowTemplate, watchers, watchersPinned;
    cellTemplate = require("./data-table-cell").template;
    rowTemplate = require("./data-table-row").template;
    cellsTemplate = "";
    watchers = {};
    cellsTemplatePinned = "";
    watchersPinned = {};
    ref = this.$children;
    for (i = 0, len = ref.length; i < len; i++) {
      child = ref[i];
      if (child.isColumn) {
        if (child.pinned) {
          this.columnsPinned.push(child);
          child.$appendTo(this.$els.pinnedHeader);
          cellsTemplatePinned += cellTemplate.replace(/{{child\.name}}/g, child.name).replace("<slot></slot>", this.fragToString(child._slotContents["default"]));
          watchersPinned[child.name + "width"] = {
            vm: child,
            prop: "width"
          };
        } else {
          this.columns.push(child);
          cellsTemplate += cellTemplate.replace("<slot></slot>", this.fragToString(child._slotContents["default"])).replace(/{{child\.name}}/g, child.name);
          watchers[child.name + "width"] = {
            vm: child,
            prop: "width"
          };
        }
      }
    }
    this.$refs.clusterize.rowWatchers = watchers;
    this.$refs.clusterize.template = rowTemplate.replace("<slot></slot>", cellsTemplate);
    if (this.columnsPinned.length > 0) {
      this.$refs.clusterizePinned.rowWatchers = watchersPinned;
      this.$refs.clusterizePinned.template = rowTemplate.replace("<slot></slot>", cellsTemplatePinned);
    }
    return this.$nextTick((function(_this) {
      return function() {
        _this.ready = true;
        if (!_this.manualStart) {
          return _this.start();
        }
      };
    })(this));
  }
};

if (module.exports.__esModule) module.exports = module.exports.default
;(typeof module.exports === "function"? module.exports.options: module.exports).template = "<div class=dt-main v-bind:style=style style=overflow:hidden><div class=dt-headers v-el:header=v-el:header style=white-space:nowrap;line-height:0><div class=dt-headers-pinned v-if=\"!started || columnsPinned.length &gt; 0\" style=display:inline-block;vertical-align:top v-el:pinned-header=v-el:pinned-header></div><div class=dt-headers-normal v-el:normal-header=v-el:normal-header style=display:inline-block;overflow:hidden;white-space:nowrap v-bind:style=\"{width:normalWidth+'px'}\"><slot></slot><div style=display:inline-block v-bind:style=\"{'width':hovered?scrollBarSize.width+'px':0}\"></div></div></div><div class=dt-contents :style=\"{height:clusterizeHeight+'px'}\" style=overflow:hidden;white-space:nowrap @mouseenter=onMouseEnter @mouseleave=onMouseLeave><div class=\"dt-content dt-content-pinned\" v-if=\"!started || columnsPinned.length &gt; 0\" style=display:inline-block;vertical-align:top;overflow:hidden;position:relative;box-sizing:border-box v-bind:style=\"{height:pinnedHeight+'px',width:pinnedWidth}\"><clusterize v-ref:clusterize-pinned=v-ref:clusterize-pinned manual-start=manual-start v-bind:parent-vm=parentVm v-bind:binding-name=bindingName v-bind:height=pinnedHeight @get-data=getData @get-data-count=getDataCount @scroll-y=onScrollY v-bind:scroll-top=scrollTop v-bind:style=\"{'overflow-y':hovered?'scroll':'hidden','position':hovered?'absolute':null,'overflow-x':'hidden'}\"></clusterize></div><div class=\"dt-content dt-content-normal\" v-el:content=v-el:content style=display:inline-block;vertical-align:top v-bind:style=\"{'max-width':normalWidth+'px'}\"><clusterize v-ref:clusterize=v-ref:clusterize manual-start=manual-start v-bind:parent-vm=parentVm v-bind:binding-name=bindingName v-bind:height=clusterizeHeight @get-data=getData @get-data-count=getDataCount v-bind:style=\"{'overflow':hovered?'scroll':'hidden'}\" @scroll-y=onScrollY @scroll-x=onScrollX v-bind:scroll-top=scrollTop></clusterize></div></div></div>"
